@@ -12,6 +12,12 @@
 #' if you write a JavaScript function called `shinyjs.myfunc`, then you can
 #' call it in R with `js$myfunc()`.
 #'
+#' It's recommended to write JavaScript code in a separate file and provide the
+#' filename as the `script` argument, but it's also possible to use the `text`
+#' argument to provide a string containing valid JavaScript code. Using the
+#' `text` argument is meant to be used when your JavaScript code is very short
+#' and simple.
+#'
 #' As a simple example, here are the steps required to add a
 #' JavaScript function that shows a message to the user (similar to
 #' \code{\link[shinyjs]{info}}):
@@ -26,6 +32,10 @@
 #'   \item In your Shiny app's UI, add a call to
 #'
 #'     \code{shinyjs::extendShinyjs("www/js/shinyjs-ext.js")}
+#'   \item Alternatively, instead of the previous three steps you can
+#'   provide the JavaScript code inline since it's fairly short:
+#'
+#'     \code{shinyjs::extendShinyjs(text = "shinyjs.myfunc = function(params) { alert(params); }")}
 #'   \item Now in your Shiny app's server you can call
 #'     \code{js$myfunc("Hello!")} and you will get a JavaScript message.
 #' }
@@ -51,7 +61,6 @@
 #'
 #'   \item \code{defaults} is an Object with key-value pairs of parameters,
 #'     where each key is a parameter name and each value is a default value.
-#'     \code{shinyjs.myfunc = function(params) { alert(params); }}
 #' }
 #' The order of the parameters in this \code{defaults} object should match the
 #' order of the parameters that users should use if they choose not to use
@@ -73,13 +82,39 @@
 #' @param script Path to a JavaScript file that contains all the functions.
 #' Each function name must begin with `shinyjs.`, for example
 #' `shinyjs.myfunc`. See 'Basic Usage' below.
+#' @param text Inline JavaScript code to use. If your JavaScript function is very
+#' short and you don't want to create a separate file for it, you can provide the
+#' code as a string. See 'Basic Usage' below.
 #' @return Scripts that \code{shinyjs} requires in order to run your JavaScript
 #' functions as if they were R code.
 #' @note You still need to call \code{useShinyjs()} as usual, and you need to
 #' call \code{useShinyjs()} before calling \code{extendShinyjs()}.
+#' @note The \code{V8} package is required to use this function.
 #' @seealso \code{\link[shinyjs]{runExample}}
 #' @examples
 #' \dontrun{
+#'   Example 1:
+#'   Change the page background to a certain colour when a button is clicked.
+#'   This example uses the `text` argument to provide short JavaScript code inline.
+#'   
+#'       library(shiny)
+#'       runApp(shinyApp(
+#'         ui = fluidPage(
+#'           useShinyjs(),
+#'           extendShinyjs(text =
+#'             "shinyjs.pageCol = function(params){$('body').css('background', params);}"),
+#'           actionButton("btn", "Click me")
+#'         ),
+#'         server = function(input, output, session) {
+#'           observeEvent(input$btn, {
+#'             js$pageCol("red")
+#'           })
+#'         }
+#'       ))
+#' 
+#'   ==============
+#' 
+#'   Example 2:
 #'   Create an `increment` function that increments the number inside an HTML
 #'   tag (increment by 1 by default, with an optional parameter).
 #'
@@ -123,23 +158,42 @@
 #'       ))
 #' }
 #' @export
-extendShinyjs <- function(script) {
+extendShinyjs <- function(script, text) {
   if (!requireNamespace("V8", quietly = TRUE)) {
     errMsg("V8 package is required to use `extendShinyjs`. Please install it.")
   }
+  
+  if (missing(script) && missing(text)) {
+    errMsg("Either `script` or `text` need to be provided.")
+  }
 
-  # create a js context with a `shinyjs` object and read user-defined functions
-  # into it
+  # create a js context with a `shinyjs` object that user-defined functions
+  # can populate
   ct <- V8::new_context(NULL, FALSE, FALSE)
   ct$assign("shinyjs", c())
-  if (!file.exists(script)) {
-    errMsg(sprintf("Could not find JavaScript file `%s`.", script))
+  
+  # read functions from a script
+  if (!missing(script)) {
+    if (!file.exists(script)) {
+      errMsg(sprintf("Could not find JavaScript file `%s`.", script))
+    }
+    tryCatch({
+      ct$source(script)
+    }, error = function(err) {
+      errMsg(sprintf("Error parsing the JavaScript file: %s.", err$message))
+    })
   }
-  tryCatch({
-    ct$source(script)
-  }, error = function(err) {
-    errMsg(sprintf("Error parsing the JavaScript file: %s", err$message))
-  })
+  
+  # read functions from in-line text
+  if (!missing(text)) {
+    tryCatch({
+      ct$eval(text)
+    }, error = function(err) {
+      errMsg(sprintf("Error parsing the JavaScript code provided.", err$message))
+    })
+  }
+  
+  # find out what functions the user defined 
   jsFuncs <- ct$get(V8::JS("Object.keys(shinyjs)"))
   if (length(jsFuncs) == 0) {
     errMsg(paste0("Could not find any shinyjs functions in the JavaScript file. ",
@@ -151,9 +205,9 @@ extendShinyjs <- function(script) {
   lapply(jsFuncs, function(x) {
     assign(x, jsFunc, js)
   })
-
+  
   # set up the message handlers for all functions
-  setupJS(script, jsFuncs)
+  setupJS(jsFuncs, script, text)
 }
 
 
