@@ -5,11 +5,13 @@ examples <- c(
   'toggle(id = "test", anim = TRUE, time = 2, animType = "slide")',
   'hide("test")',
   'show("test")',
+  'reset("expr")',
   'info(R.Version())',
   'onclick("btn", info(date()))',
   'toggleState("btn")',
   'disable("btn")',
   'enable("btn")',
+  'toggle(id = "btn", condition = (sample(2, 1) == 1))',
   'text("btn", "What a nice button")',
   'text("test", paste("The time is", date()))',
   'addClass("test", "green")',
